@@ -1,6 +1,6 @@
 package Log::Log4perl::Layout::JSON;
-$Log::Log4perl::Layout::JSON::VERSION = '0.002003';
-
+$Log::Log4perl::Layout::JSON::VERSION = '0.50';
+# ABSTRACT: Layout a log message as a JSON hash, including MDC data
 
 use 5.008;
 use strict;
@@ -15,7 +15,6 @@ use JSON::MaybeXS;
 
 use parent qw(Log::Log4perl::Layout);
 
-
 # TODO
 #   add eval around encode
 #   add way to include/exclude MDC items when include_mdc is enabled (eg by name and perhaps allow a regex)
@@ -101,6 +100,12 @@ sub BUILD { ## no critic (RequireArgUnpacking)
 
     $self->field(delete $args->{field}) if $args->{field};
 
+    # Optionally override encoding from ascii to utf8
+    if (my $arg = $args->{utf8}) {
+        delete $args->{utf8};
+        $self->codec( $self->codec->ascii(0)->utf8(1) );
+    }
+
     for my $arg_name (qw(
         canonical prefix include_mdc name_for_mdc max_json_length_kb
     )) {
@@ -128,6 +133,9 @@ sub BUILD { ## no critic (RequireArgUnpacking)
 sub render {
     my($self, $message, $category, $priority, $caller_level) = @_;
 
+    # increment caller_level to resolve caller appropriately
+    $caller_level++;
+
     my $layed_out_msg = $self->_pattern_layout->render($message, $category, $priority, $caller_level);
 
     my @fields = (
@@ -227,15 +235,13 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
-Log::Log4perl::Layout::JSON
+Log::Log4perl::Layout::JSON - Layout a log message as a JSON hash, including MDC data
 
 =head1 VERSION
 
-version 0.002003
+version 0.50
 
 =head1 SYNOPSIS
 
@@ -262,10 +268,6 @@ suitable for output, via Log::Log4perl appenders, to files and syslog etc.
 Contextual data in the L<Log::Log4perl::MDC> hash will be included if
 L</include_mdc> is true.
 
-=head1 NAME
-
-Log::Log4perl::Layout::JSON - Layout a log message as a JSON hash, including MDC data
-
 =head1 LAYOUT CONFIGURATION
 
 =head2 field
@@ -340,6 +342,10 @@ field removed.
 
 In future this rather dumb logic will be replaced by something smarter.
 
+=head2 utf8
+
+Switch JSON encoding from ASCII to UTF-8.
+
 =head2 EXAMPLE USING Log::Log4perl::MDC
 
     local Log::Log4perl::MDC->get_context->{request} = {
@@ -370,9 +376,29 @@ The use of C<local> ensures that contextual data doesn't stay in the MDC
 beyond the relevant scope. (For more complex cases you could use something like
 L<Scope::Guard> or simply take care to delete old data.)
 
+=head1 HISTORY
+
+Originally created and maintained through v0.002003 by Tim Bunce.  Versions
+0.50 and later maintained by Michael Schout <mschout@cpan.org>
+
+=for Pod::Coverage  BUILD
+ codec
+ mdc_handler
+ render
+
+=head1 SOURCE
+
+The development version is on github at L<http://github.com/mschout/Log-Log4perl-Layout-JSON>
+and may be cloned from L<git://github.com/mschout/Log-Log4perl-Layout-JSON.git>
+
+=head1 BUGS
+
+Please report any bugs or feature requests to bug-log-log4perl-layout-json@rt.cpan.org or through the web interface at:
+ http://rt.cpan.org/Public/Dist/Display.html?Name=Log-Log4perl-Layout-JSON
+
 =head1 AUTHOR
 
-Tim Bunce <Tim.Bunce@pobox.com>
+Michael Schout <mschout@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
